==> gengmei_flutter_plugin-0.0.5.tar.gz: example/lib/main.dart <==
import 'dart:io';

import 'package:flutter/material.dart';
import 'dart:async';

import 'package:gengmei_flutter_plugin/gengmei_flutter_plugin.dart';
import 'package:permission_handler/permission_handler.dart';

void main() => runApp(MyApp());

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {

  @override
  void initState() {
    super.initState();
    requestPermission();
  }

  Future requestPermission() async {
    Map<PermissionGroup, PermissionStatus> permissions =
        await PermissionHandler().requestPermissions([
      PermissionGroup.camera,
      PermissionGroup.photos,
      PermissionGroup.storage
    ]);
    // 申请结果
    PermissionStatus permission =
        await PermissionHandler().checkPermissionStatus(PermissionGroup.camera);
    PermissionStatus photoPermission =
        await PermissionHandler().checkPermissionStatus(PermissionGroup.photos);

    PermissionStatus storagePermission = await PermissionHandler()
        .checkPermissionStatus(PermissionGroup.storage);

    if (permission == PermissionStatus.granted &&
        photoPermission == PermissionStatus.granted) {
      GengmeiFlutterPlugin.phoneImages().then((value) {
        print(value);
      }).whenComplete(() {});
    } else {
      print("refuse");
    }
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Plugin example app'),
        ),
        body: Center(
        ),
      ),
    );
  }
}

==> gengmei_flutter_plugin-0.0.6.tar.gz: example/lib/main.dart <==
import 'dart:io';

import 'package:flutter/material.dart';
import 'dart:async';

import 'package:gengmei_flutter_plugin/gengmei_flutter_plugin.dart';
import 'package:permission_handler/permission_handler.dart';

void main() => runApp(MyApp());

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {

  @override
  void initState() {
    super.initState();
    requestPermission();
  }

  Future requestPermission() async {
    Map<PermissionGroup, PermissionStatus> permissions =
        await PermissionHandler().requestPermissions([
      PermissionGroup.camera,
      PermissionGroup.photos,
      PermissionGroup.storage
    ]);
    // 申请结果
    PermissionStatus permission =
        await PermissionHandler().checkPermissionStatus(PermissionGroup.camera);
    PermissionStatus photoPermission =
        await PermissionHandler().checkPermissionStatus(PermissionGroup.photos);

    PermissionStatus storagePermission = await PermissionHandler()
        .checkPermissionStatus(PermissionGroup.storage);

//    if (permission == PermissionStatus.granted &&
//        photoPermission == PermissionStatus.granted) {
      GengmeiFlutterPlugin.phoneImages().then((value) {
        print(value);
      }).whenComplete(() {});
//    } else {
//      print("refuse");
//    }
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Plugin example app'),
        ),
        body: Center(
        ),
      ),
    );
  }
}
